@@ -8,7 +8,7 @@
 #'@param includeIntercept Boolean whether the y-intercept should be included
 #'@param k The number of models or data partitions desired
 #'@param criterion Whether AIC (default), BIC, or adjustedR2 should be used to select variables
-#'@param method Whether to split data by folds ("fold") or by bootstrapping ("boot")
+#'@param method Whether to split data by folds ("fold"), nested folds ("nestedfold"), or bootstrapping ("boot")
 #'@param seed Seed for reproducibility (only needed if method is "boot")
 #'@param weights Optional vector of weights to be passed to the fitting process
 #'@param keep Optional character vector of variables to forcibly retain
@@ -65,7 +65,14 @@ ecmaveback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC", k,
   xtr <- as.data.frame(xtr)
   xtr <- data.frame(apply(xtr, 2, diff, 1))
   
+  if (class(y)=='data.frame'){
+    if (ncol(y) > 1){
+      warning("You have more than one column in y, only the first will be used")
+    }
+    y <- y[,1]
+  }
   yLag1 <- y[1:(length(y) - 1)]
+  
   x <- cbind(xtr, xeq[complete.cases(xeq), ])
   x <- cbind(x, yLag1)
   names(x) <- c(xtrnames, xeqnames, "yLag1")
